vcversioner: Python build system extension to obtain package version from version control
=========================================================================================

Description
-----------

Write a setup.py with no version information specified, and vcversioner
will find a recent, properly-formatted VCS tag and extract a version
from it.

License
-------

Python Software Foundation License


Upstream Contact
----------------

Home page: https://pypi.python.org/pypi/vcversioner/

Dependencies
------------

Python, Setuptools
